using System;
using System.Data;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.UIControls;

using TreeNode = CMS.TreeEngine.TreeNode;

public partial class CMSAdminControls_UI_Selectors_SelectImageDialog_Content_Header : CMSUserControl
{
    protected int selectedNodeId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Get selected node ID
        selectedNodeId = ValidationHelper.GetInteger(Request.Params["selectedNodeId"], 0);

        Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        string path = QueryHelper.GetString("path", "");

        btnUpload.Text = ResHelper.GetString("SelectImageDialog.Upload");
        string imagesUrl = IsLiveSite
                        ? "~/App_Themes/" + Page.Theme + "/Images/CMSFormControls/LiveSelectors/SelectImageDialog/"
                        : "~/App_Themes/" + Page.Theme + "/Images/CMSFormControls/Selectors/SelectImageDialog/";
        imgUpload.ImageUrl = imagesUrl + "upload.gif";

        // Fill in the site list
        if (drpSites.Items.Count == 0)
        {
            if (!IsLiveSite)
            {
                pnlNew.Visible = true;
            }

            // If actual user is global administrator, get all sites
            if (CMSContext.CurrentUser.IsGlobalAdministrator)
            {
                DataSet ds = SiteInfoProvider.GetSites("SiteStatus='RUNNING'", "SiteDisplayName");
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpSites.DataSource = ds.Tables[0];
                    drpSites.DataBind();
                }
            }
            // Else get only user's sites.
            else
            {
                DataTable ds = UserInfoProvider.GetUserSites(CMSContext.CurrentUser.UserID, "SiteStatus = 'RUNNING'", "SiteDisplayName", -1, null);

                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpSites.DataSource = ds;
                    drpSites.DataBind();
                }
            }

            try
            {
                drpSites.SelectedValue = CMSContext.CurrentSite.SiteID.ToString();
            }
            catch
            {
            }

            // Disable selecting other sites from dropdownlist when starting path is defined or public user
            if ((CMSContext.CurrentUser.IsPublic() && IsLiveSite) || (path != ""))
            {
                drpSites.Enabled = false;
            }
        }
        drpSites.Attributes.Add("onchange", "RefreshSite(this);");

        // Set tree URL
        string treeUrl = "tree.aspx" + Request.Url.Query;
        if (treeUrl.IndexOf("?") >= 0)
        {
            treeUrl += "&siteid=";
        }
        else
        {
            treeUrl += "?siteid=";
        }
        ltlScript.Text += ScriptHelper.GetScript("var treeUrl = '" + treeUrl + "'; var selectElem = document.getElementById('" + drpSites.ClientID + "'); RefreshSite();");
    }


    protected void btnUpload_Click(object sender, EventArgs e)
    {
        // Selected node info
        TreeNode node = null;

        // CMS.File class info
        DataClassInfo dci = null;

        // Indicates wheather cms.file child class is allowed
        bool isAllowed = false;

        if (selectedNodeId > 0)
        {
            // Get selected node info
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            node = tree.SelectSingleNode(selectedNodeId, TreeProvider.ALL_CULTURES);

            // Get cms.file class id
            dci = DataClassInfoProvider.GetDataClass("cms.file");

            if ((node != null) && (dci != null))
            {
                // Check wheather cms.file child class is allowed
                isAllowed = DataClassInfoProvider.IsChildClassAllowed(ValidationHelper.GetInteger(node.GetValue("NodeClassID"), 0), dci.ClassID);
            }
        }

        if (isAllowed)
        {
            // Open 'Upload' dialog window            
            ltlScript.Text += ScriptHelper.GetScript("modalDialog('" + ResolveUrl("~/CMSDesk/Content/EditFrameset.aspx?action=new&nodeid=" + selectedNodeId + "&classid=" + dci.ClassID + "&dialog=1") + "', 'UploadFile', 600, 280)");
        }
        else
        {
            // Show error message
            ltlScript.Text += ScriptHelper.GetAlertScript(ResHelper.GetString("SelectImageDialog_CMSFileNotAllowed"));
        }
    }
}
